/*
 * Copyright (C) 2009 Collabora Ltd <http://www.collabora.co.uk>
 * Copyright (C) 2009 Abner Silva <abner.silva@kdemail.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef ACCOUNTWIDGET_H
#define ACCOUNTWIDGET_H

// Plasma
#include <Plasma/Frame>

#include "presencewidget.h"

namespace Plasma
{
    class Label;
}

class QGraphicsGridLayout;
class AccountImage;
class PresenceWidget;

class AccountWidget : public Plasma::Frame
{
    Q_OBJECT

public:
    AccountWidget(QGraphicsWidget *parent = 0);
    ~AccountWidget();

    void init();

    void setId(const QString &id);
    QString id() const;

    void setName(const QString &name);
    QString name() const;

    void setAlias(const QString &alias);
    QString alias() const;

    void setImage(const QPixmap &image);

    void setPresence(const QString &presence, const QString &msg);
    QString presenceStatus() const;
    QString presenceMessage() const;

Q_SIGNALS:
    void presenceChanged(const QString &presence, const QString &msg);

private Q_SLOTS:
    void onPresenceStatusChanged(PresenceWidget::PresenceStatus status,
            const QString &text);

private:
    QString presenceStatusToString(PresenceWidget::PresenceStatus status) const;
    QString m_id;
    AccountImage *m_image;
    QGraphicsGridLayout* m_layout;
    Plasma::Label *m_accountNameLabel;
    Plasma::Label *m_accountAliasLabel;
    PresenceWidget *m_presenceWidget;
};

#endif
