/*
 * Copyright (C) 2009 Collabora Ltd <http://www.collabora.co.uk>
 * Copyright (C) 2009 Abner Silva <abner.silva@kdemail.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

// Own
#include "globalpresencewidget.h"

// Plasma
#include <Plasma/Theme>
#include <Plasma/Frame>

// Kde
#include <KColorScheme>
#include <KDebug>

//Qt
#include <QGraphicsLinearLayout>

using namespace Plasma;

GlobalPresenceWidget::GlobalPresenceWidget(QGraphicsWidget *parent)
    : Frame(parent),
      m_layout(0),
      m_presenceWidget(0),
      m_status(PresenceWidget::Offline),
      m_statusMessage("")
{
    init();
    setMinimumHeight(55);
    setMinimumWidth(230);
    setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
}

GlobalPresenceWidget::~GlobalPresenceWidget()
{
}

void GlobalPresenceWidget::init()
{
    kDebug() << "GlobalPresenceWidget::init: initializing";

    m_layout = new QGraphicsLinearLayout(this);
    m_layout->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);

    m_presenceWidget = new PresenceWidget(this);
    connect (m_presenceWidget,
            SIGNAL(presenceStatusChanged(PresenceWidget::PresenceStatus,
                                         const QString&)),
            this, SLOT(onPresenceStatusChanged(PresenceWidget::PresenceStatus,
                                               const QString&)));
    m_layout->addItem(m_presenceWidget);
    m_layout->setAlignment(m_presenceWidget, Qt::AlignBottom | Qt::AlignCenter);

    setLayout(m_layout);
}

void GlobalPresenceWidget::setPresenceStatus(const QString &presence)
{
    PresenceWidget::PresenceStatus status = PresenceWidget::Offline;

    if (presence.contains("available"))
        status = PresenceWidget::Online;
    else if (presence.contains("away"))
        status = PresenceWidget::Away;
    else if (presence.contains("busy"))
        status = PresenceWidget::Busy;
    else if (presence.contains("invisible"))
        status = PresenceWidget::Invisible;
    else if (presence.contains("offline"))
        status = PresenceWidget::Offline;

    m_presenceWidget->setPresenceStatus(status);
    m_status = status;
}

void GlobalPresenceWidget::setPresenceMessage(const QString &msg)
{
    m_presenceWidget->setPresenceMessage(msg);
    m_statusMessage = msg;
}

void GlobalPresenceWidget::onPresenceStatusChanged(PresenceWidget::PresenceStatus status,
        const QString &text)
{
    if (m_status != status) {
        QString ret;

        switch(status) {
            case PresenceWidget::Online:
                ret = "available";
                break;
            case PresenceWidget::Away:
                ret = "away";
                break;
            case PresenceWidget::Busy:
                ret = "busy";
                break;
            case PresenceWidget::Invisible:
                ret = "invisible";
                break;
            case PresenceWidget::Offline:
                ret = "offline";
                break;
            default:
                break;
        }
        m_status = status;
        emit presenceStatusChanged(ret);
    }

    if (m_statusMessage != text) {
        m_statusMessage = text;
        emit presenceMessageChanged(text);
    }
}
#include "globalpresencewidget.moc"
