/*
 * Copyright (C) 2009 Collabora Ltd <http://www.collabora.co.uk>
 * Copyright (C) 2009 Abner Silva <abner.silva@kdemail.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef PRESENCEWIDGET_H
#define PRESENCEWIDGET_H

// Qt
#include <QGraphicsWidget>

namespace Plasma
{
    class LineEdit;
    class Label;
    class IconWidget;
}

class QGraphicsLinearLayout;
class QTimer;

class PresenceWidget : public QGraphicsWidget
{
    Q_OBJECT
    Q_PROPERTY(PresenceStatus presenceStatus READ presenceStatus WRITE setPresenceStatus)
    Q_PROPERTY(QString presenceMessage READ presenceMessage WRITE setPresenceMessage)

public:
    enum PresenceStatus {
        Online = 1,
        Away = 2,
        Busy = 3,
        Invisible = 4,
        Offline = 5
    };

    PresenceWidget(QGraphicsWidget *parent = 0);
    ~PresenceWidget();

    void init();

    void setPresenceStatus(PresenceStatus status);
    PresenceStatus presenceStatus() const;

    void setPresenceMessage(const QString &msg);
    const QString presenceMessage() const;

    void setPresenceStatusWithMsg(PresenceStatus status, const QString &msg);

Q_SIGNALS:
    void presenceStatusChanged(PresenceWidget::PresenceStatus status,
            const QString &msg);

private Q_SLOTS:
    void onNewStatusClicked();
    void onPresenceStatusSwitch();
    void onPresenceMsgReturn();
    void onPresenceMsgSwitch();

private:
    QGraphicsLinearLayout *m_layout;
    QGraphicsLinearLayout *m_iconsLayout;
    QGraphicsWidget *m_iconsWidget;
    Plasma::IconWidget *m_currentStatusIcon;
    QGraphicsLinearLayout *m_currentStatusLayout;
    QGraphicsWidget *m_currentStatusWidget;
    Plasma::LineEdit *m_presenceMessage;
    Plasma::Label *m_presenceMessageLabel;
    QString m_presenceMsg;
    QHash<PresenceStatus, Plasma::IconWidget *> m_status;
    PresenceStatus m_currentStatus;
    QGraphicsLinearLayout *m_waitLayout;
    QGraphicsWidget *m_waitWidget;
    QTimer *m_waitTimer;
};

#endif
